@@ -20,7 +20,7 @@ calculatecentroid <- function(beta){
 
 innerprod_q2 <- function(q1, q2){
     T1 = ncol(q1)
-    val = sum(sum(q1*q2))/T1
+    val = trapz(seq(0,1,length.out=T1),colSums(q1*q2))
 
     return(val)
 }
@@ -324,6 +324,8 @@ inverse_exp_coord <- function(beta1, beta2, mode="O", rotated=T){
 
     if (mode=="C"){
       isclosed = TRUE
+    } else {
+      isclosed = FALSE
     }
 
     # Iteratively optimize over SO(n) x Gamma using old DP
@@ -347,11 +349,11 @@ inverse_exp_coord <- function(beta1, beta2, mode="O", rotated=T){
     }
 
     # Compute geodesic distance
-    q1dotq2 = innerprod_q2(q1, q2n)
+    q1dotq2 = innerprod_q2(q1/sqrt(innerprod_q2(q1, q1)), q2n/sqrt(innerprod_q2(q2n, q2n)))
     if (q1dotq2>1){
       q1dotq2 = 1.
     }
-    
+
     dist = acos(q1dotq2)
 
     u = q2n - q1dotq2 * q1
@@ -396,7 +398,7 @@ inverse_exp <- function(q1, q2, beta2){
     if (q1dotq2>1){
         q1dotq2 = 1.
     }
-    
+
     dist = acos(q1dotq2)
 
     u = q2 - q1dotq2 * q1
