@@ -9,10 +9,10 @@
 #' @param lambda controls amount of warping (default = 0)
 #' @param method controls which optimization method (default="DP") options are
 #' Dynamic Programming ("DP"), Coordinate Descent ("DP2"), Riemannian BFGS
-#' ("RBFGS") and Simultaneous Alignment ("SIMUL")
+#' ("RBFGS"), Simultaneous Alignment ("SIMUL"), Dirchelet Bayesian ("dBayes"),
+#' and Expo-Map Bayesian ("expBayes")
 #' @param w controls LRBFGS (default = 0.01)
-#' @param f1o initial value of f1, vector or scalar depending on q1, defaults to zero
-#' @param f2o initial value of f2, vector or scalar depending on q1, defaults to zero
+#' @param iter number of mcmc iterations for mcmc method (default 2000)
 #' @return Returns a list containing \item{f2tilde}{aligned f2}
 #' \item{gam}{warping function}
 #' @keywords srsf alignment
@@ -22,17 +22,28 @@
 #' @references Tucker, J. D., Wu, W., Srivastava, A.,
 #'  Generative Models for Function Data using Phase and Amplitude Separation,
 #'  Computational Statistics and Data Analysis (2012), 10.1016/j.csda.2012.12.001.
+#' @references Cheng, W., Dryden, I. L., and Huang, X. (2016). Bayesian
+#'  registration of functions and curves. Bayesian Analysis, 11(2), 447-475.
+#' @references Lu, Y., Herbei, R., and Kurtek, S. (2017). Bayesian registration
+#'  of functions with a Gaussian process prior. Journal of Computational and
+#'  Graphical Statistics, DOI: 10.1080/10618600.2017.1336444.
 #' @export
 #' @examples
 #' data("simu_data")
 #' out = pair_align_functions(simu_data$f[,1],simu_data$f[,2],simu_data$time)
-pair_align_functions <- function(f1, f2, time,lambda=0,method="DP",w=0.01,
-                                 f1o=0.0, f2o=0.0){
+pair_align_functions <- function(f1, f2, time, lambda=0, method="DP", w=0.01, iter=2000){
 
   q1 = f_to_srvf(f1, time)
   q2 = f_to_srvf(f2, time)
-  gam = optimum.reparam(q1, time, q2, time, lambda, method, w, f1o, f2o)
-  f2_aligned = warp_f_gamma(f2, time, gam)
+  if (method=="dBayes"){
+    gam <- pair_align_functions_bayes(f1, f2, time, iter=iter)$gam_a
+  } else if (method=="expBayes") {
+    gam <- pair_align_functions_expomap(f1, f2, time, iter=iter)$gamma
+  } else {
+    gam <- optimum.reparam(q1, time, q2, time, lambda, method, w, f1o=f1[1], f2o=f2[1])
+  }
+
+  f2_aligned <- warp_f_gamma(f2, time, gam)
 
   return(list(f2tilde=f2_aligned, gam=gam))
 }
